function C = consortium(t,y)

% UBC iGEM 2016 Consortium Model
% Experiments done by David Goertsen, 4th Year Undergraduate Chemical and Biological Engineering Student
% MATLAB coding and modeling by David Goertsen
% Thanks Tarryn Monteiro for keeping me going

cmax = 0.156; % hr-1 Max specific growth rate for C. crescentus
emax = 0.484; % hr^-1 Max specific growth rate for e.coli
Ksc = 0.403; %mM Monod Constant for C. crescentus
Kse = 0.403; %mM Monod Constant for E.coli
Km = 0.03; %mM Michaelis-Menten Constant
a = 0.003; %Replaces Xc due to the lack of prokaryote concentration dependance on rate

Yc = 0.476; % OD600 / g glucose 
Ye = 0.2; % OD600 / g glucose 

MWg = 180.16; % g glucose/mol glucose

%y(1) is Caulobacter concentration
%y(2) is E coli concentration
%y(3) is Cellulose Concentration
%y(4) is Glucose Concentration

dxdt1 = y(1)*cmax*exp(-y(1))*y(4)/(Ksc + y(4));
dxdt2 = y(2)*emax*exp(-y(2)^2)*y(4)/(Kse + y(4));
dCdt = -a*y(3)/(Km + y(3));
dSdt = 2*a*y(3)/(Km + y(3)) - y(1)*cmax*exp(-y(1))*y(4)*1000/(Ksc + y(4))/(Yc*MWg) - y(2)*emax*exp(-2*y(2)^2)*y(4)*1000/(Kse + y(4))/(Yc*MWg);


C = [dxdt1; dxdt2; dCdt; dSdt];
end



